@@ -1,4 +1,9 @@
-from django.conf.urls.defaults import include, patterns, url
+try:
+    # Django >= 1.4
+    from django.conf.urls import include, patterns, url
+except ImportError:
+    # Django 1.3
+    from django.conf.urls.defaults import include, patterns, url
 
 from . import admin_views
 from . import fiber_admin
